//
//  CakeMobileConversions.h
//  CakeSDKLessConversionCode
//
//  Created by Ryan Newsome on 11/29/12.
//  Copyright (c) 2014 Ryan Newsome. All rights reserved.
//
/**************************************************************************************

 Description: This class is a helper file to be used with the Cake Marketing tracking system
 to register conversions in the form of an install and register events. When used properly this will send a conversion
 postback to a cake instance once and allow events to be sent which may or may not be unique.
 
 Example usage:
 
 //Uncomment this code to ensure the conversion is always sent otherwise it will only be sent once
 //This should only be used for testing purposes and disabled for production
 //[CakeMobileConversions setDebugMode:YES];
 
 //Add a conversion key to the postback
 if([ASIdentifierManager class] && [[ASIdentifierManager sharedManager] advertisingIdentifier] != nil)
 {
    [CakeMobileConversions addConversionKey:[[[ASIdentifierManager sharedManager] advertisingIdentifier] UUIDString]];
 }
 
 //Send the conversion. The URL string should be for the given offer.
 [CakeMobileConversions sendInstallConversionWithURLString:@"http://www.mytrackingdomain.com?p.ashx?o=1234"];
 
 //Send an event at a later point in the app
 [CakeMobileConversions sendEventWithURLString:@"http://www.mytrackingdomain.com?p.ashx?o=1234&t=e" doesAllowDuplicates:NO];

***************************************************************************************/

#import <Foundation/Foundation.h>

@interface CakeMobileConversions : NSObject <NSXMLParserDelegate>

/**************************************************************************************
 *                               Cake Conversion Setup functions
 ***************************************************************************************/

// This is set to NO by default. If set to YES conversion attempts will always be sent
// and not check for internet connection and whether a conversion has already been sent.
// This should be set to NO before the app is submitted.
+ (void)setDebugMode:(BOOL)isDebug;

// Pass in any string value to be used as a conversion key in the
// conversion postback
+ (void)addConversionKey:(NSString*)keyString;

/**************************************************************************************
 *                               Conversion API
 ***************************************************************************************/
// This will send a conversion postback to the url specified including all conversion keys specified
// and the reqid if it has been set. Any other parameters that are wanted can be added to the URLString.
//
// This will only be sent once. If there is no internet connection the conversion will not
// attempt to be sent and will be attempted the next time the function
// is called and there is a network connection
//
// ************************************ Parameters ***************************************
//
// URLString(string) - Base string of the url which must contain at least "?o=[offer_id]" as a parameter
//
// ****************************************************************************************
//
//
+ (void)sendInstallConversionWithURLString:(NSString*)URLString;

/**************************************************************************************
 *                               Event API
***************************************************************************************/
// This will send an event to the specified URL string.
//
// If allowDuplicates is passed in as YES it will allow you to send the same event twice but if it is NO
// then you can call this function as many times as you want without duplicates being sent.
//
// ************************************ Parameters ***************************************
//
// URLString(string) - Base string of the url which must contain at least "?o=[offer_id]" as a parameter
//
// allowDuplicates(BOOL) - Determines if the specific event will allow duplicates to be sent.
//
// ****************************************************************************************
//
//
+ (void)sendEventWithURLString:(NSString*)URLString doesAllowDuplicates:(BOOL)allowDuplicates;

@end
